PlatformInfo class abstract
An interface for providing platform-specific information.
This interface is used to abstract platform-specific checks, making it easier to test code that depends on platform information.
- Implementers
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited