PlatformInfo class abstract

An interface for providing platform-specific information.

This interface is used to abstract platform-specific checks, making it easier to test code that depends on platform information.

Implementers

Constructors

PlatformInfo()

Properties

hashCode int
The hash code for this object.
no setterinherited
isWeb bool
Returns true if the application is running in a web browser.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited